pytilities.aop.aspects — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »

# pytilities.aop.aspects

Some reusable aspects and aspect factories

Contents

- ImmutableAspect
- create_view()

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »